==> dif-database-repository-2.7.1-sources.jar: pt/digitalis/dif/dem/managers/impl/model/data/ReportTemplateAreaSql.java <==
package pt.digitalis.dif.dem.managers.impl.model.data;


import java.util.ArrayList;
import java.util.List;
import org.hibernate.Session;
import pt.digitalis.dif.model.dataset.HibernateDataSet;
import pt.digitalis.dif.model.dataset.IDataSet;
import pt.digitalis.dif.model.hibernate.HibernateUtil;
import pt.digitalis.dif.model.utils.AbstractBeanRelationsAttributes;
import pt.digitalis.dif.model.utils.IBeanAttributesDataSet;

/**
 * ReportTemplateAreaSql
* Generated on ORM Generator
* DIF build process for the Model layer
*
*/
@SuppressWarnings("serial")
public class ReportTemplateAreaSql extends AbstractBeanRelationsAttributes implements java.io.Serializable, IBeanAttributesDataSet<ReportTemplateAreaSql> {

    /** ReportTemplateAreaSql attributes enumeration */
    public static class Fields
    {
        /** id column */
        public static final String ID ="id";
        /** name column */
        public static final String NAME ="name";
        /** sql column */
        public static final String SQL ="sql";

        /**
         * List of existing fields
         *
         * @return list of field names
         */
        public static List<String> values()
        {
            ArrayList<String> list = new ArrayList<String>();
            list.add("id");
            list.add("name");
            list.add("sql");

            return list;
        }
    }

    /** Field attributes */
    public static ReportTemplateAreaSqlFieldAttributes FieldAttributes=new ReportTemplateAreaSqlFieldAttributes();

    /**
    * @return the field attributes definitions
    */
    @Override public ReportTemplateAreaSqlFieldAttributes getDefinitions()
    {
        return FieldAttributes;
    }

    /**
     * The Class Relations.
     */
    public class Relations extends AbstractBeanRelationsAttributes.AbstractRelations
    {

        /**
        * Instantiates a new relations.
        *
        * @param currentPath the current path
        */
        public Relations(String currentPath)
        {
            super(currentPath);
        }
        /**
         * sqlDataSource relation.
         *
         * @return the sqlDataSource bean relations attributes.
         */
        public SqlDataSource.Relations sqlDataSource()
        {
            SqlDataSource c = new SqlDataSource();
            return c.new Relations(this.buildPath("sqlDataSource"));
        }

        /**
         * reportTemplateArea relation.
         *
         * @return the reportTemplateArea bean relations attributes.
         */
        public ReportTemplateArea.Relations reportTemplateArea()
        {
            ReportTemplateArea c = new ReportTemplateArea();
            return c.new Relations(this.buildPath("reportTemplateArea"));
        }

        /**
         * the ID path.
         *
         * @return the path
         */
        public String ID()
        {
            return buildPath(Fields.ID);
        }
        /**
         * the NAME path.
         *
         * @return the path
         */
        public String NAME()
        {
            return buildPath(Fields.NAME);
        }
        /**
         * the SQL path.
         *
         * @return the path
         */
        public String SQL()
        {
            return buildPath(Fields.SQL);
        }
    }

    /** The dummy obj. */
    private static ReportTemplateAreaSql dummyObj=new ReportTemplateAreaSql();

    /**
     * Get ReportTemplateAreaSql Relations .
     *
     * @return the relations
     */
    public static Relations FK()
    {
        return dummyObj.new Relations(null);
    }

    /**
    * Gets a new dataSet object for this bean
    *
    * @return the dataSet
    */
    public IDataSet<ReportTemplateAreaSql> getDataSet()
    {
        return new HibernateDataSet<ReportTemplateAreaSql>(ReportTemplateAreaSql.class, HibernateUtil.getSessionFactory("DIFRepository"),
            ReportTemplateAreaSql.getPKFieldListAsString(), ReportTemplateAreaSql.FieldAttributes);
    }

    /**
    * Gets a new dataSet object for this bean
    *
    * @return the dataSet
    */
    public static IDataSet<ReportTemplateAreaSql> getDataSetInstance()
    {
        return new ReportTemplateAreaSql().getDataSet();
    }

    /**
    * @see pt.digitalis.dif.model.utils.AbstractBeanAttributes#getAttributeNoGraphNavigation(java.lang.String)
    */
    @Override protected Object getAttributeNoGraphNavigation(String attributeName)
    {
        if("id".equalsIgnoreCase(attributeName))
            return id;
        if("sqlDataSource".equalsIgnoreCase(attributeName))
            return sqlDataSource;
        if("reportTemplateArea".equalsIgnoreCase(attributeName))
            return reportTemplateArea;
        if("name".equalsIgnoreCase(attributeName))
            return name;
        if("sql".equalsIgnoreCase(attributeName))
            return sql;

        return null;
    }

    /**
    * @see pt.digitalis.utils.common.IBeanAttributes#setAttribute(java.lang.String, java.lang.Object)
    */
    public void setAttribute(String attributeName,Object attributeValue)
    {
        if("id".equalsIgnoreCase(attributeName))
            id =(Long)attributeValue;
        if("sqlDataSource".equalsIgnoreCase(attributeName))
            sqlDataSource =(SqlDataSource)attributeValue;
        if("reportTemplateArea".equalsIgnoreCase(attributeName))
            reportTemplateArea =(ReportTemplateArea)attributeValue;
        if("name".equalsIgnoreCase(attributeName))
            name =(String)attributeValue;
        if("sql".equalsIgnoreCase(attributeName))
            sql =(String)attributeValue;
    }

    // Fields

    /** id private attribute */
    private Long id;

    /** sqlDataSource private attribute */
    private SqlDataSource sqlDataSource;

    /** reportTemplateArea private attribute */
    private ReportTemplateArea reportTemplateArea;

    /** name private attribute */
    private String name;

    /** sql private attribute */
    private String sql;

    /** The pojo's primary key field list names */
    private static List<String> pkFieldList;

    /**
     * Get the table fields that compose the PK
     *
     * @return the PK field list
     */
     public synchronized static List<String> getPKFieldList()
     {
         if (pkFieldList == null)
         {
             pkFieldList = new ArrayList<String>();
             pkFieldList.add("id");
         }

         return pkFieldList;
     }

    /**
     * Get the table fields that compose the PK as a comma separated field name list
     *
     * @return the PK field list as a string
     */
     public static String getPKFieldListAsString()
     {
         StringBuffer buffer = new StringBuffer();

         for (int i = 0; i < getPKFieldList().size(); i++)
         {
             if (i != 0)
                 buffer.append(",");

             buffer.append(getPKFieldList().get(i));
         }

         return buffer.toString();
     }

    /**
     * @see pt.digitalis.dif.model.utils.AbstractBeanAttributes#getAttributeAsString(java.lang.String)
     */
     @Override
     public String getAttributeAsString(String attributeName)
     {

        Object value = getAttribute(attributeName);

        if (value == null)
            return "";
        else {
            return value.toString().trim();
        }
     }

    // Constructors

    /**
     * default constructor
     */
    public ReportTemplateAreaSql() {
    }

	/** 
	 * minimal constructor
	 *
     * @param reportTemplateArea the reportTemplateArea
     * @param name the name
     * @param sql the sql
    }
	 */
    public ReportTemplateAreaSql(ReportTemplateArea reportTemplateArea, String name, String sql) {
        this.reportTemplateArea = reportTemplateArea;
        this.name = name;
        this.sql = sql;
    }

    /**
     * full constructor
	 *
     * @param sqlDataSource the sqlDataSource
     * @param reportTemplateArea the reportTemplateArea
     * @param name the name
     * @param sql the sql
     */
    public ReportTemplateAreaSql(SqlDataSource sqlDataSource, ReportTemplateArea reportTemplateArea, String name, String sql) {
        this.sqlDataSource = sqlDataSource;
        this.reportTemplateArea = reportTemplateArea;
        this.name = name;
        this.sql = sql;
    }

    // Property accessors
    
    /**       
     * id getter method
     *
     * @return id method
     */
    public Long getId() {
        return this.id;
    }
    
    /**       
     * id setter method
     *
     * @param id the id
     *
     * @return ReportTemplateAreaSql modified instance
     */
    public ReportTemplateAreaSql setId(Long id) {
        this.id = id;
        
        return this;
    }
    /**       
     * sqlDataSource getter method
     *
     * @return sqlDataSource method
     */
    public SqlDataSource getSqlDataSource() {
        return this.sqlDataSource;
    }
    
    /**       
     * sqlDataSource setter method
     *
     * @param sqlDataSource the sqlDataSource
     *
     * @return ReportTemplateAreaSql modified instance
     */
    public ReportTemplateAreaSql setSqlDataSource(SqlDataSource sqlDataSource) {
        this.sqlDataSource = sqlDataSource;
        
        return this;
    }
    /**       
     * reportTemplateArea getter method
     *
     * @return reportTemplateArea method
     */
    public ReportTemplateArea getReportTemplateArea() {
        return this.reportTemplateArea;
    }
    
    /**       
     * reportTemplateArea setter method
     *
     * @param reportTemplateArea the reportTemplateArea
     *
     * @return ReportTemplateAreaSql modified instance
     */
    public ReportTemplateAreaSql setReportTemplateArea(ReportTemplateArea reportTemplateArea) {
        this.reportTemplateArea = reportTemplateArea;
        
        return this;
    }
    /**       
     * name getter method
     *
     * @return name method
     */
    public String getName() {
        return this.name;
    }
    
    /**       
     * name setter method
     *
     * @param name the name
     *
     * @return ReportTemplateAreaSql modified instance
     */
    public ReportTemplateAreaSql setName(String name) {
        this.name = name;
        
        return this;
    }
    /**       
     * sql getter method
     *
     * @return sql method
     */
    public String getSql() {
        return this.sql;
    }
    
    /**       
     * sql setter method
     *
     * @param sql the sql
     *
     * @return ReportTemplateAreaSql modified instance
     */
    public ReportTemplateAreaSql setSql(String sql) {
        this.sql = sql;
        
        return this;
    }

    /**
     * Creates a String representation of the ReportTemplateAreaSql object
     *
     * @return the compiled String
     */
    @Override
    public String toString() {
	    StringBuffer buffer = new StringBuffer();

        buffer.append(getClass().getName()).append("@").append(Integer.toHexString(hashCode())).append(" [");

        buffer.append("id").append("='").append(getId()).append("' ");			
        buffer.append("name").append("='").append(getName()).append("' ");			
        buffer.append("sql").append("='").append(getSql()).append("' ");			
        buffer.append("]");
      
        return buffer.toString();
    }

    /**
     * Compares the String representation of the ReportTemplateAreaSql object
     *
     * @param other The object to compare to
     *
     * @return true of the objects are equal
     */
    public boolean equals(ReportTemplateAreaSql other) {
        	return this.toString().equals(other.toString());
    }
    /**
     * @see pt.digitalis.utils.common.IBeanAttributes#setAttributeFromString(java.lang.String, java.lang.String)
     */
    public void setAttributeFromString(String attributeName, String attributeValue) {
        if ("id".equalsIgnoreCase(attributeName))
            this.id = Long.valueOf(attributeValue);

        if ("name".equalsIgnoreCase(attributeName))
        	this.name = attributeValue;

        if ("sql".equalsIgnoreCase(attributeName))
        	this.sql = attributeValue;

    }


    /**
     * Instanciates an Hibernate proxy data object (does not load it from the database, provides lazy load for that)
     *
     * @param session the session
     * @param id      the id
     *
     * @return the proxy
     */
    public static ReportTemplateAreaSql getProxy(Session session, Long id)
    {
        return(ReportTemplateAreaSql)session.load(ReportTemplateAreaSql.class,id);
    }

    /**
    * Instanciates an Hibernate proxy data object (does not load it from the database, provides lazy load for that)
    *
    * @param id      the id
    *
    * @return the proxy
    */
    public static ReportTemplateAreaSql getProxy(Long id)
    {
        Session session = HibernateUtil.getSessionFactory("DIFRepository").getCurrentSession();
        boolean wasActive = session.getTransaction().isActive();

        if (!wasActive)
            session.beginTransaction();

        ReportTemplateAreaSql result = (ReportTemplateAreaSql)session.load(ReportTemplateAreaSql.class,id);

        if (!wasActive)
            session.getTransaction().commit();

        return result;
    }


    /**
     * Instanciates an Hibernate data object
     *
     * @param session the session
     * @param id      the id
     *
     * @return the instance
     */
    public static ReportTemplateAreaSql getInstance(Session session, Long id)
    {
        return(ReportTemplateAreaSql)session.get(ReportTemplateAreaSql.class,id);
    }

    /**
    * Instanciates an Hibernate data object
    *
    * @param id      the id
    *
    * @return the instance
    */
    public static ReportTemplateAreaSql getInstance(Long id)
    {
        Session session = HibernateUtil.getSessionFactory("DIFRepository").getCurrentSession();
        boolean wasActive = session.getTransaction().isActive();

        if (!wasActive)
            session.beginTransaction();

        ReportTemplateAreaSql result = (ReportTemplateAreaSql)session.get(ReportTemplateAreaSql.class,id);

        if (!wasActive)
            session.getTransaction().commit();

        return result;
    }

}

==> dif-database-repository-2.7.3-5-sources.jar: pt/digitalis/dif/dem/managers/impl/model/data/ReportTemplateAreaSql.java <==
package pt.digitalis.dif.dem.managers.impl.model.data;


import java.util.ArrayList;
import java.util.List;
import org.hibernate.Session;
import pt.digitalis.dif.model.dataset.HibernateDataSet;
import pt.digitalis.dif.model.dataset.IDataSet;
import pt.digitalis.dif.model.hibernate.HibernateUtil;
import pt.digitalis.dif.model.utils.AbstractBeanRelationsAttributes;
import pt.digitalis.dif.model.utils.IBeanAttributesDataSet;

/**
 * ReportTemplateAreaSql
* Generated on ORM Generator
* DIF build process for the Model layer
*
*/
@SuppressWarnings("serial")
public class ReportTemplateAreaSql extends AbstractBeanRelationsAttributes implements java.io.Serializable, IBeanAttributesDataSet<ReportTemplateAreaSql> {

    /**
    * Constant with the session factory ID
    */
    public static String SESSION_FACTORY_NAME = "DIFRepository";

    /** ReportTemplateAreaSql attributes enumeration */
    public static class Fields
    {
        /** id column */
        public static final String ID ="id";
        /** name column */
        public static final String NAME ="name";
        /** sql column */
        public static final String SQL ="sql";

        /**
         * List of existing fields
         *
         * @return list of field names
         */
        public static List<String> values()
        {
            ArrayList<String> list = new ArrayList<String>();
            list.add("id");
            list.add("name");
            list.add("sql");

            return list;
        }
    }

    /** Field attributes */
    public static ReportTemplateAreaSqlFieldAttributes FieldAttributes=new ReportTemplateAreaSqlFieldAttributes();

    /**
    * @return the field attributes definitions
    */
    @Override public ReportTemplateAreaSqlFieldAttributes getDefinitions()
    {
        return FieldAttributes;
    }

    /**
     * The Class Relations.
     */
    public class Relations extends AbstractBeanRelationsAttributes.AbstractRelations
    {

        /**
        * Instantiates a new relations.
        *
        * @param currentPath the current path
        */
        public Relations(String currentPath)
        {
            super(currentPath);
        }
        /**
         * sqlDataSource relation.
         *
         * @return the sqlDataSource bean relations attributes.
         */
        public SqlDataSource.Relations sqlDataSource()
        {
            SqlDataSource c = new SqlDataSource();
            return c.new Relations(this.buildPath("sqlDataSource"));
        }

        /**
         * reportTemplateArea relation.
         *
         * @return the reportTemplateArea bean relations attributes.
         */
        public ReportTemplateArea.Relations reportTemplateArea()
        {
            ReportTemplateArea c = new ReportTemplateArea();
            return c.new Relations(this.buildPath("reportTemplateArea"));
        }

        /**
         * the ID path.
         *
         * @return the path
         */
        public String ID()
        {
            return buildPath(Fields.ID);
        }
        /**
         * the NAME path.
         *
         * @return the path
         */
        public String NAME()
        {
            return buildPath(Fields.NAME);
        }
        /**
         * the SQL path.
         *
         * @return the path
         */
        public String SQL()
        {
            return buildPath(Fields.SQL);
        }
    }

    /** The dummy obj. */
    private static ReportTemplateAreaSql dummyObj=new ReportTemplateAreaSql();

    /**
     * Get ReportTemplateAreaSql Relations .
     *
     * @return the relations
     */
    public static Relations FK()
    {
        return dummyObj.new Relations(null);
    }

    /**
    * Gets a new dataSet object for this bean
    *
    * @return the dataSet
    */
    public IDataSet<ReportTemplateAreaSql> getDataSet()
    {
        return getDataSetInstance();
    }

    /**
    * Gets a new dataSet object for this bean
    *
    * @return the dataSet
    */
    public static IDataSet<ReportTemplateAreaSql> getDataSetInstance()
    {
        return new HibernateDataSet<ReportTemplateAreaSql>(ReportTemplateAreaSql.class, HibernateUtil.getSessionFactory(SESSION_FACTORY_NAME),
            ReportTemplateAreaSql.getPKFieldListAsString(), ReportTemplateAreaSql.FieldAttributes);
    }

    /**
    * @see pt.digitalis.dif.model.utils.AbstractBeanAttributes#getAttributeNoGraphNavigation(java.lang.String)
    */
    @Override protected Object getAttributeNoGraphNavigation(String attributeName)
    {
        if("id".equalsIgnoreCase(attributeName))
            return id;
        if("sqlDataSource".equalsIgnoreCase(attributeName))
            return sqlDataSource;
        if("reportTemplateArea".equalsIgnoreCase(attributeName))
            return reportTemplateArea;
        if("name".equalsIgnoreCase(attributeName))
            return name;
        if("sql".equalsIgnoreCase(attributeName))
            return sql;

        return null;
    }

    /**
    * @see pt.digitalis.utils.common.IBeanAttributes#setAttribute(java.lang.String, java.lang.Object)
    */
    public void setAttribute(String attributeName,Object attributeValue)
    {
        if("id".equalsIgnoreCase(attributeName))
            id =(Long)attributeValue;
        if("sqlDataSource".equalsIgnoreCase(attributeName))
            sqlDataSource =(SqlDataSource)attributeValue;
        if("reportTemplateArea".equalsIgnoreCase(attributeName))
            reportTemplateArea =(ReportTemplateArea)attributeValue;
        if("name".equalsIgnoreCase(attributeName))
            name =(String)attributeValue;
        if("sql".equalsIgnoreCase(attributeName))
            sql =(String)attributeValue;
    }

    // Fields

    /** id private attribute */
    private Long id;

    /** sqlDataSource private attribute */
    private SqlDataSource sqlDataSource;

    /** reportTemplateArea private attribute */
    private ReportTemplateArea reportTemplateArea;

    /** name private attribute */
    private String name;

    /** sql private attribute */
    private String sql;

    /** The pojo's primary key field list names */
    private static List<String> pkFieldList;

    /**
     * Get the table fields that compose the PK
     *
     * @return the PK field list
     */
     public synchronized static List<String> getPKFieldList()
     {
         if (pkFieldList == null)
         {
             pkFieldList = new ArrayList<String>();
             pkFieldList.add("id");
         }

         return pkFieldList;
     }

    /**
     * Get the table fields that compose the PK as a comma separated field name list
     *
     * @return the PK field list as a string
     */
     public static String getPKFieldListAsString()
     {
         StringBuffer buffer = new StringBuffer();

         for (int i = 0; i < getPKFieldList().size(); i++)
         {
             if (i != 0)
                 buffer.append(",");

             buffer.append(getPKFieldList().get(i));
         }

         return buffer.toString();
     }

    /**
     * Gets description field.
     *
     * @return the description field
     */
    @Override
    public String getDescriptionField()
    {
        return FieldAttributes.getDescriptionField();
    }

    /**
     * Get the table fields that compose the PK
     *
     * @return the PK field list
     */
    @Override
    public List<String> getPKFields()
    {
        return getPKFieldList();
    }

    /**
     * Is composite PK.
     *
     * @return the boolean
     */
    @Override
    public boolean isCompositePK()
    {
        return this.getPKFieldList().size() > 1;
    }

    /**
     * @see pt.digitalis.dif.model.utils.AbstractBeanAttributes#getAttributeAsString(java.lang.String)
     */
     @Override
     public String getAttributeAsString(String attributeName)
     {
        if (attributeName.contains("."))
        {
            return this.getAttributeAsStringParseBeanPath(attributeName);
        }
        else
        {
            Object value = getAttribute(attributeName);

            if (value == null)
                return "";
            else {
                return value.toString().trim();
            }
        }
     }

    // Constructors

    /**
     * default constructor
     */
    public ReportTemplateAreaSql() {
    }

	/** 
	 * minimal constructor
	 *
     * @param reportTemplateArea the reportTemplateArea
     * @param name the name
     * @param sql the sql
    }
	 */
    public ReportTemplateAreaSql(ReportTemplateArea reportTemplateArea, String name, String sql) {
        this.reportTemplateArea = reportTemplateArea;
        this.name = name;
        this.sql = sql;
    }

    /**
     * full constructor
	 *
     * @param sqlDataSource the sqlDataSource
     * @param reportTemplateArea the reportTemplateArea
     * @param name the name
     * @param sql the sql
     */
    public ReportTemplateAreaSql(SqlDataSource sqlDataSource, ReportTemplateArea reportTemplateArea, String name, String sql) {
        this.sqlDataSource = sqlDataSource;
        this.reportTemplateArea = reportTemplateArea;
        this.name = name;
        this.sql = sql;
    }

    // Property accessors
    
    /**       
     * id getter method
     *
     * @return id method
     */
    public Long getId() {
        return this.id;
    }
    
    /**       
     * id setter method
     *
     * @param id the id
     *
     * @return ReportTemplateAreaSql modified instance
     */
    public ReportTemplateAreaSql setId(Long id) {
        this.id = id;
        
        return this;
    }
    /**       
     * sqlDataSource getter method
     *
     * @return sqlDataSource method
     */
    public SqlDataSource getSqlDataSource() {
        return this.sqlDataSource;
    }
    
    /**       
     * sqlDataSource setter method
     *
     * @param sqlDataSource the sqlDataSource
     *
     * @return ReportTemplateAreaSql modified instance
     */
    public ReportTemplateAreaSql setSqlDataSource(SqlDataSource sqlDataSource) {
        this.sqlDataSource = sqlDataSource;
        
        return this;
    }
    /**       
     * reportTemplateArea getter method
     *
     * @return reportTemplateArea method
     */
    public ReportTemplateArea getReportTemplateArea() {
        return this.reportTemplateArea;
    }
    
    /**       
     * reportTemplateArea setter method
     *
     * @param reportTemplateArea the reportTemplateArea
     *
     * @return ReportTemplateAreaSql modified instance
     */
    public ReportTemplateAreaSql setReportTemplateArea(ReportTemplateArea reportTemplateArea) {
        this.reportTemplateArea = reportTemplateArea;
        
        return this;
    }
    /**       
     * name getter method
     *
     * @return name method
     */
    public String getName() {
        return this.name;
    }
    
    /**       
     * name setter method
     *
     * @param name the name
     *
     * @return ReportTemplateAreaSql modified instance
     */
    public ReportTemplateAreaSql setName(String name) {
        this.name = name;
        
        return this;
    }
    /**       
     * sql getter method
     *
     * @return sql method
     */
    public String getSql() {
        return this.sql;
    }
    
    /**       
     * sql setter method
     *
     * @param sql the sql
     *
     * @return ReportTemplateAreaSql modified instance
     */
    public ReportTemplateAreaSql setSql(String sql) {
        this.sql = sql;
        
        return this;
    }

    /**
     * sqlDataSource id getter method
     *
     * @return sqlDataSource id method
     */
    public Long getSqlDataSourceId() {
        if (this.sqlDataSource == null)
            return null;
        else
            return this.sqlDataSource.getId();
    }

    /**
     * SqlDataSource proxy setter method from id.
     *
     * @return ReportTemplateAreaSql modified instance
     */
    public ReportTemplateAreaSql setSqlDataSourceProxyFromId(Long id)
    {
        if (id == null || id.equals(-1L))
            this.sqlDataSource = null;
        else
            this.sqlDataSource = SqlDataSource.getProxy(id);

        return this;
    }

    /**
     * SqlDataSource instance setter method from id.
     *
     * @return ReportTemplateAreaSql modified instance
     */
    public ReportTemplateAreaSql setSqlDataSourceInstanceFromId(Long id)
    {
        if (id == null || id.equals(-1L))
            this.sqlDataSource = null;
        else
            this.sqlDataSource = SqlDataSource.getInstance(id);

        return this;
    }
    /**
     * reportTemplateArea id getter method
     *
     * @return reportTemplateArea id method
     */
    public Long getReportTemplateAreaId() {
        if (this.reportTemplateArea == null)
            return null;
        else
            return this.reportTemplateArea.getId();
    }

    /**
     * ReportTemplateArea proxy setter method from id.
     *
     * @return ReportTemplateAreaSql modified instance
     */
    public ReportTemplateAreaSql setReportTemplateAreaProxyFromId(Long id)
    {
        if (id == null || id.equals(-1L))
            this.reportTemplateArea = null;
        else
            this.reportTemplateArea = ReportTemplateArea.getProxy(id);

        return this;
    }

    /**
     * ReportTemplateArea instance setter method from id.
     *
     * @return ReportTemplateAreaSql modified instance
     */
    public ReportTemplateAreaSql setReportTemplateAreaInstanceFromId(Long id)
    {
        if (id == null || id.equals(-1L))
            this.reportTemplateArea = null;
        else
            this.reportTemplateArea = ReportTemplateArea.getInstance(id);

        return this;
    }

    /**
     * Creates a String representation of the ReportTemplateAreaSql object
     *
     * @return the compiled String
     */
    @Override
    public String toString() {
	    StringBuffer buffer = new StringBuffer();

        buffer.append(getClass().getName()).append("@").append(Integer.toHexString(hashCode())).append(" [");

        buffer.append("id").append("='").append(getId()).append("' ");			
        buffer.append("name").append("='").append(getName()).append("' ");			
        buffer.append("sql").append("='").append(getSql()).append("' ");			
        buffer.append("]");
      
        return buffer.toString();
    }

    /**
     * Compares the String representation of the ReportTemplateAreaSql object
     *
     * @param other The object to compare to
     *
     * @return true of the objects are equal
     */
    public boolean equals(ReportTemplateAreaSql other) {
        	return this.toString().equals(other.toString());
    }
    /**
     * @see pt.digitalis.utils.common.IBeanAttributes#setAttributeFromString(java.lang.String, java.lang.String)
     */
    public void setAttributeFromString(String attributeName, String attributeValue) {
        if ("id".equalsIgnoreCase(attributeName))
            this.id = Long.valueOf(attributeValue);

        if ("name".equalsIgnoreCase(attributeName))
        	this.name = attributeValue;

        if ("sql".equalsIgnoreCase(attributeName))
        	this.sql = attributeValue;

    }


    /**
     * Instanciates an Hibernate proxy data object (does not load it from the database, provides lazy load for that)
     *
     * @param session the session
     * @param id      the id
     *
     * @return the proxy
     */
    public static ReportTemplateAreaSql getProxy(Session session, Long id)
    {
        return(ReportTemplateAreaSql)session.load(ReportTemplateAreaSql.class,id);
    }

    /**
    * Instanciates an Hibernate proxy data object (does not load it from the database, provides lazy load for that)
    *
    * @param id      the id
    *
    * @return the proxy
    */
    public static ReportTemplateAreaSql getProxy(Long id)
    {
        Session session = HibernateUtil.getSessionFactory(SESSION_FACTORY_NAME).getCurrentSession();
        boolean wasActive = session.getTransaction().isActive();

        if (!wasActive)
            session.beginTransaction();

        ReportTemplateAreaSql result = (ReportTemplateAreaSql)session.load(ReportTemplateAreaSql.class,id);

        if (!wasActive)
            session.getTransaction().commit();

        return result;
    }


    /**
     * Instanciates an Hibernate data object
     *
     * @param session the session
     * @param id      the id
     *
     * @return the instance
     */
    public static ReportTemplateAreaSql getInstanceForSession(Session session, Long id)
    {
        return(ReportTemplateAreaSql)session.get(ReportTemplateAreaSql.class,id);
    }

    /**
    * Instanciates an Hibernate data object
    *
    * @param id      the id
    *
    * @return the instance
    */
    public static ReportTemplateAreaSql getInstance(Long id)
    {
        Session session = HibernateUtil.getSessionFactory(SESSION_FACTORY_NAME).getCurrentSession();
        boolean wasActive = session.getTransaction().isActive();

        if (!wasActive)
            session.beginTransaction();

        ReportTemplateAreaSql result = (ReportTemplateAreaSql)session.get(ReportTemplateAreaSql.class,id);

        if (!wasActive)
            session.getTransaction().commit();

        return result;
    }

}
